==> sumus-6.3.1-sources.jar: io/intino/sumus/graph/MeasureIndicator.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import java.util.List;
import io.intino.sumus.datawarehouse.store.Digest;


public class MeasureIndicator extends io.intino.sumus.graph.Indicator implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.AbstractMetric.Unit unit;
	protected java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList = new java.util.ArrayList<>();

	public MeasureIndicator(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.AbstractMetric.Unit unit() {
		return unit;
	}

	public MeasureIndicator unit(io.intino.sumus.graph.AbstractMetric.Unit value) {
		this.unit = value;
		return (MeasureIndicator) this;
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList() {
		return java.util.Collections.unmodifiableList(formulaList);
	}

	public io.intino.sumus.graph.MeasureIndicator.Formula formula(int index) {
		return formulaList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator.Formula> predicate) {
		return formulaList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(formulaList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("unit", this.unit != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.unit)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("MeasureIndicator$Formula")) this.formulaList.add(node.as(io.intino.sumus.graph.MeasureIndicator.Formula.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("MeasureIndicator$Formula")) this.formulaList.remove(node.as(io.intino.sumus.graph.MeasureIndicator.Formula.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("unit")) this.unit = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.AbstractMetric.Unit.class, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("unit")) this.unit = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.AbstractMetric.Unit.class) : null;
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Indicator.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.MeasureIndicator.Formula formula(io.intino.sumus.graph.Cube cube, io.intino.sumus.graph.functions.Calculate calculate) {
		    io.intino.sumus.graph.MeasureIndicator.Formula newElement = core$().graph().concept(io.intino.sumus.graph.MeasureIndicator.Formula.class).createNode(name, core$()).as(io.intino.sumus.graph.MeasureIndicator.Formula.class);
			newElement.core$().set(newElement, "cube", java.util.Collections.singletonList(cube));
			newElement.core$().set(newElement, "calculate", java.util.Collections.singletonList(calculate));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void formula(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator.Formula> filter) {
			new java.util.ArrayList<>(formulaList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Formula extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Cube cube;
		protected io.intino.sumus.graph.functions.Calculate calculate;

		public Formula(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Cube cube() {
			return cube;
		}

		public double calculate(List<Digest> digests) {
			return calculate.calculate(digests);
		}

		public Formula cube(io.intino.sumus.graph.Cube value) {
			this.cube = value;
			return (Formula) this;
		}

		public Formula calculate(io.intino.sumus.graph.functions.Calculate value) {
			this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(calculate, this, io.intino.sumus.graph.functions.Calculate.class);
			return (Formula) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("cube", this.cube != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.cube)) : java.util.Collections.emptyList());
			map.put("calculate", this.calculate != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.calculate)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("cube")) this.cube = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Cube.class, this).get(0);
			else if (name.equalsIgnoreCase("calculate")) this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.Calculate.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("cube")) this.cube = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Cube.class) : null;
			else if (name.equalsIgnoreCase("calculate")) this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.Calculate.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/MeasureIndicator.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import java.util.List;
import io.intino.sumus.datawarehouse.store.Digest;


public class MeasureIndicator extends io.intino.sumus.graph.Indicator implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.AbstractMetric.Unit unit;
	protected java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList = new java.util.ArrayList<>();

	public MeasureIndicator(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.AbstractMetric.Unit unit() {
		return unit;
	}

	public MeasureIndicator unit(io.intino.sumus.graph.AbstractMetric.Unit value) {
		this.unit = value;
		return (MeasureIndicator) this;
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList() {
		return java.util.Collections.unmodifiableList(formulaList);
	}

	public io.intino.sumus.graph.MeasureIndicator.Formula formula(int index) {
		return formulaList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator.Formula> formulaList(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator.Formula> predicate) {
		return formulaList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(formulaList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("unit", this.unit != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.unit)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("MeasureIndicator$Formula")) this.formulaList.add(node.as(io.intino.sumus.graph.MeasureIndicator.Formula.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("MeasureIndicator$Formula")) this.formulaList.remove(node.as(io.intino.sumus.graph.MeasureIndicator.Formula.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("unit")) this.unit = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.AbstractMetric.Unit.class, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("unit")) this.unit = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.AbstractMetric.Unit.class) : null;
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Indicator.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.MeasureIndicator.Formula formula(io.intino.sumus.graph.Cube cube, io.intino.sumus.graph.functions.Calculate calculate) {
		    io.intino.sumus.graph.MeasureIndicator.Formula newElement = core$().graph().concept(io.intino.sumus.graph.MeasureIndicator.Formula.class).createNode(this.name, core$()).as(io.intino.sumus.graph.MeasureIndicator.Formula.class);
			newElement.core$().set(newElement, "cube", java.util.Collections.singletonList(cube));
			newElement.core$().set(newElement, "calculate", java.util.Collections.singletonList(calculate));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void formula(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator.Formula> filter) {
			new java.util.ArrayList<>(formulaList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Formula extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Cube cube;
		protected io.intino.sumus.graph.functions.Calculate calculate;

		public Formula(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Cube cube() {
			return cube;
		}

		public double calculate(List<Digest> digests) {
			return calculate.calculate(digests);
		}

		public Formula cube(io.intino.sumus.graph.Cube value) {
			this.cube = value;
			return (Formula) this;
		}

		public Formula calculate(io.intino.sumus.graph.functions.Calculate value) {
			this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(calculate, this, io.intino.sumus.graph.functions.Calculate.class);
			return (Formula) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("cube", this.cube != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.cube)) : java.util.Collections.emptyList());
			map.put("calculate", this.calculate != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.calculate)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("cube")) this.cube = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Cube.class, this).get(0);
			else if (name.equalsIgnoreCase("calculate")) this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.Calculate.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("cube")) this.cube = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Cube.class) : null;
			else if (name.equalsIgnoreCase("calculate")) this.calculate = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.Calculate.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
